@@ -297,14 +297,19 @@ class RuleCondorcetVtbIRV(Rule):
     Fabien Mathieu and Ludovic Noirie, 2014.
     """
 
+    full_name = 'Condorcet IRV'
+    abbreviation = 'CIRV'
+
+    options_parameters = Rule.options_parameters.copy()
+    options_parameters.update({
+        'cm_option': {'allowed': {'fast', 'slow', 'very_slow', 'exact'}, 'default': 'fast'},
+        'tm_option': {'allowed': ['exact'], 'default': 'exact'},
+        'icm_option': {'allowed': {'exact'}, 'default': 'exact'}
+    })
+
     def __init__(self, **kwargs):
         # self.irv_ = None
         super().__init__(
-            options_parameters={
-                'cm_option': {'allowed': {'fast', 'slow', 'very_slow', 'exact'}, 'default': 'fast'},
-                'tm_option': {'allowed': ['exact'], 'default': 'exact'},
-                'icm_option': {'allowed': {'exact'}, 'default': 'exact'}
-            },
             with_two_candidates_reduces_to_plurality=True, is_based_on_rk=True,
             precheck_um=False, precheck_icm=False,
             log_identity="CONDORCET_VTB_IRV", **kwargs
