@@ -1,9 +1,9 @@
-from svvamp import ProfileGeneratorNoisedFile
+from svvamp import GeneratorProfileNoisedFile
 import os
 
 
 def test():
     file = os.path.join(os.path.dirname(__file__), 'example_ballots.t.csv')
-    profile = ProfileGeneratorNoisedFile(file_name=file, relative_noise=.01, absolute_noise=.01)()
+    profile = GeneratorProfileNoisedFile(file_name=file, relative_noise=.01, absolute_noise=.01)()
     assert profile.preferences_ut.shape == (86, 11)
     assert len(profile.labels_candidates) == 11
